==> jc-1.4.0.tar.gz: soot/coffi/Exception__5fattribute.h <==
// public class soot.coffi.Exception_attribute

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6151fa947e4a8315 soot_coffi_Exception__5fattribute
// @dep_class 49e6b7ec550acdca soot_coffi_attribute__5finfo

// header file dependencies
// @dep_header soot_coffi_attribute__5finfo

#include "soot/coffi/attribute__5finfo.h"

#ifndef _JC_soot_coffi_Exception__5fattribute_H_
#define _JC_soot_coffi_Exception__5fattribute_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Exception__5fattribute$sub_refs	_jc_soot_coffi_Exception__5fattribute$sub_refs;
typedef struct _jc_soot_coffi_Exception__5fattribute$sub_nonrefs	_jc_soot_coffi_Exception__5fattribute$sub_nonrefs;
typedef struct _jc_soot_coffi_Exception__5fattribute$refs	_jc_soot_coffi_Exception__5fattribute$refs;
typedef struct _jc_soot_coffi_Exception__5fattribute$nonrefs	_jc_soot_coffi_Exception__5fattribute$nonrefs;
typedef struct _jc_soot_coffi_Exception__5fattribute$object	_jc_soot_coffi_Exception__5fattribute$object;

typedef const struct _jc_soot_coffi_Exception__5fattribute$vmethods	_jc_soot_coffi_Exception__5fattribute$vmethods;
typedef const struct _jc_soot_coffi_Exception__5fattribute$vtable	_jc_soot_coffi_Exception__5fattribute$vtable;
typedef const struct _jc_soot_coffi_Exception__5fattribute$vtype	_jc_soot_coffi_Exception__5fattribute$vtype;

// Constructors
extern void _jc_soot_coffi_Exception__5fattribute$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Exception__5fattribute$object *);

// Virtual methods structure
struct _jc_soot_coffi_Exception__5fattribute$vmethods {
};

// Vtable
struct _jc_soot_coffi_Exception__5fattribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_attribute__5finfo$vmethods	soot_coffi_attribute__5finfo;
	_jc_soot_coffi_Exception__5fattribute$vmethods	soot_coffi_Exception__5fattribute;
};

// Vtype
struct _jc_soot_coffi_Exception__5fattribute$vtype {
	_jc_type			type;
	_jc_soot_coffi_Exception__5fattribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Exception__5fattribute$sub_refs {
	_jc_int_array	*exception__5findex__5ftable;
};

// Reference instance fields (object)
struct _jc_soot_coffi_Exception__5fattribute$refs {
    _jc_soot_coffi_Exception__5fattribute$sub_refs	soot_coffi_Exception__5fattribute;
    _jc_soot_coffi_attribute__5finfo$sub_refs	soot_coffi_attribute__5finfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Exception__5fattribute$sub_nonrefs {
	jint	number__5fof__5fexceptions;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Exception__5fattribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_attribute__5finfo$sub_nonrefs	soot_coffi_attribute__5finfo;
    _jc_soot_coffi_Exception__5fattribute$sub_nonrefs	soot_coffi_Exception__5fattribute;
};

// Object instance structure
struct _jc_soot_coffi_Exception__5fattribute$object {
	_jc_soot_coffi_Exception__5fattribute$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Exception__5fattribute$vtype	*vtype;
	_jc_soot_coffi_Exception__5fattribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Exception__5fattribute$vtype _jc_soot_coffi_Exception__5fattribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Exception__5fattribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Exception__5fattribute$class_object;

#endif	/* _JC_soot_coffi_Exception__5fattribute_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Exception__5fattribute.h <==
// public class soot.coffi.Exception_attribute

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6151fa947e4a8315 soot_coffi_Exception__5fattribute
// @dep_class 49e6b7ec550acdca soot_coffi_attribute__5finfo

// header file dependencies
// @dep_header soot_coffi_attribute__5finfo

#include "soot/coffi/attribute__5finfo.h"

#ifndef _JC_soot_coffi_Exception__5fattribute_H_
#define _JC_soot_coffi_Exception__5fattribute_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Exception__5fattribute$sub_refs	_jc_soot_coffi_Exception__5fattribute$sub_refs;
typedef struct _jc_soot_coffi_Exception__5fattribute$sub_nonrefs	_jc_soot_coffi_Exception__5fattribute$sub_nonrefs;
typedef struct _jc_soot_coffi_Exception__5fattribute$refs	_jc_soot_coffi_Exception__5fattribute$refs;
typedef struct _jc_soot_coffi_Exception__5fattribute$nonrefs	_jc_soot_coffi_Exception__5fattribute$nonrefs;
typedef struct _jc_soot_coffi_Exception__5fattribute$object	_jc_soot_coffi_Exception__5fattribute$object;

typedef const struct _jc_soot_coffi_Exception__5fattribute$vmethods	_jc_soot_coffi_Exception__5fattribute$vmethods;
typedef const struct _jc_soot_coffi_Exception__5fattribute$vtable	_jc_soot_coffi_Exception__5fattribute$vtable;
typedef const struct _jc_soot_coffi_Exception__5fattribute$vtype	_jc_soot_coffi_Exception__5fattribute$vtype;

// Constructors
extern void _jc_soot_coffi_Exception__5fattribute$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Exception__5fattribute$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Exception__5fattribute$vmethods {
};

// Vtable
struct _jc_soot_coffi_Exception__5fattribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_attribute__5finfo$vmethods	soot_coffi_attribute__5finfo;
	_jc_soot_coffi_Exception__5fattribute$vmethods	soot_coffi_Exception__5fattribute;
};

// Vtype
struct _jc_soot_coffi_Exception__5fattribute$vtype {
	_jc_type			type;
	_jc_soot_coffi_Exception__5fattribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Exception__5fattribute$sub_refs {
	_jc_int_array	*exception__5findex__5ftable;
};

// Reference instance fields (object)
struct _jc_soot_coffi_Exception__5fattribute$refs {
    _jc_soot_coffi_Exception__5fattribute$sub_refs	soot_coffi_Exception__5fattribute;
    _jc_soot_coffi_attribute__5finfo$sub_refs	soot_coffi_attribute__5finfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Exception__5fattribute$sub_nonrefs {
	jint	number__5fof__5fexceptions;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Exception__5fattribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_attribute__5finfo$sub_nonrefs	soot_coffi_attribute__5finfo;
    _jc_soot_coffi_Exception__5fattribute$sub_nonrefs	soot_coffi_Exception__5fattribute;
};

// Object instance structure
struct _jc_soot_coffi_Exception__5fattribute$object {
	_jc_soot_coffi_Exception__5fattribute$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Exception__5fattribute$vtype	*vtype;
	_jc_soot_coffi_Exception__5fattribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Exception__5fattribute$vtype _jc_soot_coffi_Exception__5fattribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Exception__5fattribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Exception__5fattribute$class_object;

#endif	/* _JC_soot_coffi_Exception__5fattribute_H_ */
